@@ -50,7 +50,7 @@ rtf_encode_table <- function(tbl, verbose = FALSE) {
   start_rtf <- paste(
 
     as_rtf_init(),
-    as_rtf_font(),
+    as_rtf_font(tbl),
     as_rtf_color(tbl),
     sep = "\n"
   )
