@@ -1,5 +1,4 @@
 # create testing example
-svg(tempfile("tmp.svg"))
 
 font <- 2:3
 format <- matrix(c("", "i", "b", "ib"), nrow = 4, ncol = 2, byrow = FALSE)
@@ -174,5 +173,3 @@ test_that("test for rtf-nrow() if 'rtf-nrow' attributes are added correctly for
 test_that("test for rtf-nrow() if 'rtf-nrow' attributes are added correctly for pageby_row table", {
   expect_equal(irspagebyrows[1], 1)
 })
-
-dev.off()
